@@ -451,6 +451,7 @@ coef.H2OCoxPHModelSummary <- function(object, ...) object@summary$coefficients
 #' @param fit an \code{H2OCoxPHModel} object.
 #' @param scale optional numeric specifying the scale parameter of the model.
 #' @param k numeric specifying the weight of the equivalent degrees of freedom.
+#' @export
 extractAIC.H2OCoxPHModel <- function(fit, scale, k = 2, ...) {
   fun <- get("extractAIC.coxph", getNamespace("stats"))
   if (missing(scale))
@@ -672,6 +673,9 @@ setClass("H2OBinomialUpliftMetrics",    contains="H2OModelMetrics")
 #' @export
 setMethod("show", "H2OBinomialUpliftMetrics", function(object) {
     callNextMethod(object)  # call to the super
+    cat("ATE: ", object@metrics$ate, "\n", sep="" )
+    cat("ATT: ", object@metrics$atc, "\n", sep="" )
+    cat("ATC: ", object@metrics$att, "\n", sep="" )
     cat("Default AUUC:  ", object@metrics$AUUC, "\n", sep="")
     cat("All types of AUUC:  ", "\n", sep="")
     print(object@metrics$auuc_table)
